About
=====

*aco2sass* is a small python script which converts photoshop `.aco` swatch files 
to a list of the corresponding swatch colors formatted as SASS varibles.

The implementation is based on the file format specified by `Adobe` here::

    https://www.adobe.com/devnet-apps/photoshop/fileformatashtml/#50577411_pgfId-1055819
